@@ -1,6 +1,5 @@
 /* asn1Coding.c --- program to generate a DER coding of an ASN1 definition.
- * Copyright (C) 2002, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
- * Foundation, Inc.
+ * Copyright (C) 2002-2012 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -34,9 +33,9 @@
 
 /* This feature is available in gcc versions 2.5 and later.  */
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
-# define ATTR_NO_RETRUN
+#define ATTR_NO_RETRUN
 #else
-# define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
+#define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
 #endif
 
 ATTR_NO_RETRUN static void
@@ -320,7 +319,8 @@ main (int argc, char *argv[])
 
       if (outputFile == NULL)
 	{
-	  printf ("asn1Coding: output file '%s' not available\n", outputFileName);
+	  printf ("asn1Coding: output file '%s' not available\n",
+		  outputFileName);
 	  free (der);
 	  free (inputFileAsnName);
 	  free (inputFileAssignmentName);
